@@ -5,8 +5,12 @@ function(language = "en", probs = FALSE, model = NULL)
     description <-
         sprintf("Computes POS tag annotations using the Apache OpenNLP Maxent Part of Speech tagger employing %s",
                 environment(f)$info)
+    for(tag in c("POS_tagset", "POS_tagset_URL")) {
+        if(!is.na(val <- environment(f)$meta[[tag]]))
+	    attr(f, tag) <- val
+    }
 
-    Simple_POS_Tag_Annotator(f, description)
+    Simple_POS_Tag_Annotator(f, list(description = description))
 }
     
 Maxent_Simple_POS_Tagger <-
@@ -41,6 +45,21 @@ function(language = "en", probs = FALSE, model = NULL)
     }
     else
         "a user-defined model"
+    
+    meta <- if(language == "en") {
+        c(POS_tagset = "en-ptb",
+          POS_tagset_URL =
+              "http://www.comp.leeds.ac.uk/ccalas/tagsets/upenn.html")
+    } else {
+        package <- sprintf("openNLPmodels.%s", language)
+        meta <- system.file("models",
+                            sprintf("%s-pos-maxent.dcf", language),
+                            package = package)
+        if(meta == "")
+            character()
+        else
+            read.dcf(meta)[1L, ]
+    }
 
     ## See
     ## <http://opennlp.apache.org/documentation/1.5.3/manual/opennlp.html#tools.postagger.tagging.api>.
